===============================
kenjutsu
===============================


.. image:: https://img.shields.io/pypi/v/kenjutsu.svg
        :target: https://pypi.python.org/pypi/kenjutsu

.. image:: https://img.shields.io/travis/jakirkham/kenjutsu/master.svg
        :target: https://travis-ci.org/jakirkham/kenjutsu

.. image:: https://readthedocs.org/projects/kenjutsu/badge/?version=latest
        :target: https://kenjutsu.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://coveralls.io/repos/github/jakirkham/kenjutsu/badge.svg
        :target: https://coveralls.io/github/jakirkham/kenjutsu
        :alt: Coveralls

.. image:: https://img.shields.io/github/license/jakirkham/kenjutsu.svg
        :target: ./LICENSE.txt
        :alt: License


Python utility functions for slices.


* Free software: BSD 3-Clause
* Documentation: https://kenjutsu.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `nanshe-org/nanshe-cookiecutter`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`nanshe-org/nanshe-cookiecutter`: https://github.com/nanshe-org/nanshe-cookiecutter

